// Copyright (c) 2026 The Chromium Embedded Framework Authors. All rights
// reserved. Use of this source code is governed by a BSD-style license that
// can be found in the LICENSE file.
//
// ---------------------------------------------------------------------------
//
// This file was generated by the CEF translator tool. If making changes by
// hand only do so within the body of existing method and function
// implementations. See the translator.README.txt file in the tools directory
// for more information.
//
// $hash=31cb2e0facb691c5494df1bda3b39258db118ad7$
//

#ifndef CEF_LIBCEF_DLL_CPPTOC_TEST_API_VERSION_TEST_REF_PTR_CLIENT_CHILD_V2_CPPTOC_H_
#define CEF_LIBCEF_DLL_CPPTOC_TEST_API_VERSION_TEST_REF_PTR_CLIENT_CHILD_V2_CPPTOC_H_
#pragma once

#if !defined(WRAPPING_CEF_SHARED)
#error This file can be included wrapper-side only
#endif

#include "include/capi/test/cef_api_version_test_capi.h"
#include "include/test/cef_api_version_test.h"
#include "libcef_dll/cpptoc/cpptoc_ref_counted.h"

#if CEF_API_ADDED(13302)

// Wrap a C++ class with a C structure.
// This class may be instantiated and accessed wrapper-side only.
class CefApiVersionTestRefPtrClientChildV2CppToC
    : public CefCppToCRefCounted<
          CefApiVersionTestRefPtrClientChildV2CppToC,
          CefApiVersionTestRefPtrClientChildV2,
          cef_api_version_test_ref_ptr_client_child_v2_t> {
public:
  CefApiVersionTestRefPtrClientChildV2CppToC();
  virtual ~CefApiVersionTestRefPtrClientChildV2CppToC();
};

constexpr auto CefApiVersionTestRefPtrClientChildV2CppToC_Wrap =
    CefApiVersionTestRefPtrClientChildV2CppToC::Wrap;
constexpr auto CefApiVersionTestRefPtrClientChildV2CppToC_Unwrap =
    CefApiVersionTestRefPtrClientChildV2CppToC::Unwrap;

#endif // CEF_API_ADDED(13302)

#endif // CEF_LIBCEF_DLL_CPPTOC_TEST_API_VERSION_TEST_REF_PTR_CLIENT_CHILD_V2_CPPTOC_H_
